<div>
    <span style="vertical-align: middle; width: 80px; height: 20px; background-color: {{ color }}; display: inline-block;"></span>
    <span style="vertical-align: middle;">{{ text }}</span>
</div>
